@@ -45,34 +45,48 @@ class Payloop:
     def attribution(
         self,
         parent_id=None,
-        parent_uuid=None,
         parent_name=None,
         subsidiary_id=None,
-        subsidiary_uuid=None,
         subsidiary_name=None,
+        # -- Deprecated parameters! They are here for backwards compatibility only.
+        parent_uuid=None,
+        subsidiary_uuid=None,
     ):
-        if parent_id is not None:
-            if not isinstance(parent_id, int):
-                raise RuntimeError("parent ID must be an integer")
+        if parent_id is None:
+            raise RuntimeError("a string parent_id is required")
+
+        parent_id = str(parent_id)
+
+        if len(parent_id) > 255:
+            raise RuntimeError("parent_id cannot be greater than 255 characters")
+
+        if parent_name is not None and len(parent_name) > 255:
+            raise RuntimeError("parent_name cannot be greater than 255 characters")
+
+        if subsidiary_name is not None and subsidiary_id is None:
+            raise RuntimeError(
+                "a string subsidiary_id is required if a subsidiary_name is provided"
+            )
 
         if subsidiary_id is not None:
-            if not isinstance(subsidiary_id, int):
-                raise RuntimeError("subsidiary ID must be an integer")
+            subsidiary_id = str(subsidiary_id)
 
-        parent = None
-        if parent_id is not None or parent_uuid is not None:
-            parent = {"id": parent_id, "name": parent_name, "uuid": parent_uuid}
+            if len(subsidiary_id) > 255:
+                raise RuntimeError(
+                    "subsidiary_id cannot be greater than 255 characters"
+                )
+
+        if subsidiary_name is not None and len(subsidiary_name) > 255:
+            raise RuntimeError("subsidiary_name cannot be greater than 255 characters")
 
         subsidiary = None
-        if subsidiary_id is not None or subsidiary_uuid is not None:
-            subsidiary = {
-                "id": subsidiary_id,
-                "name": subsidiary_name,
-                "uuid": subsidiary_uuid,
-            }
+        if subsidiary_id is not None:
+            subsidiary = {"id": subsidiary_id, "name": subsidiary_name}
 
-        if parent is not None or subsidiary is not None:
-            self.config.attribution = {"parent": parent, "subsidiary": subsidiary}
+        self.config.attribution = {
+            "parent": {"id": parent_id, "name": parent_name},
+            "subsidiary": subsidiary,
+        }
 
         return self
 
