@@ -144,6 +144,25 @@ class BaseInvoke:
 
         return formatted_response
 
+    def get_response_content(self, raw_response):
+        if (
+            raw_response.__class__.__name__ == "LegacyAPIResponse"
+            and raw_response.__class__.__module__ == "openai._legacy_response"
+        ):
+            """
+            Library: langchain-openai
+            Version: > 0.3.31
+
+            Calling the chat / invoke method of the client no longer returns the JSON
+            response but instead an object that looks like an API response. This
+            object does not inherit from a base class we can reliably identify and
+            we do not want to force the OpenAI library as a dependency.
+            """
+
+            return json.loads(raw_response.text)
+
+        return raw_response
+
     def list_to_json(self, list_):
         result = []
         for entry in list_:
