@@ -59,7 +59,7 @@ class Invoke(BaseInvoke):
                     start,
                     time.time(),
                     self._format_kwargs(kwargs),
-                    self._format_response(raw_response),
+                    self._format_response(self.get_response_content(raw_response)),
                 )
             )
 
@@ -82,7 +82,7 @@ class InvokeAsync(BaseInvoke):
                 start,
                 time.time(),
                 self._format_kwargs(kwargs),
-                self._format_response(raw_response),
+                self._format_response(self.get_response_content(raw_response)),
             )
         )
 
@@ -113,7 +113,7 @@ class InvokeAsyncIterator(BaseInvoke):
                     start,
                     time.time(),
                     self._format_kwargs(kwargs),
-                    self._format_response(raw_response),
+                    self._format_response(self.get_response_content(raw_response)),
                 )
             )
 
@@ -141,7 +141,7 @@ class InvokeAsyncStream(BaseInvoke):
                 start,
                 time.time(),
                 self._format_kwargs(kwargs),
-                self._format_response(raw_response),
+                self._format_response(self.get_response_content(raw_response)),
             )
         )
 
@@ -162,7 +162,7 @@ class InvokeStream(BaseInvoke):
                 start,
                 time.time(),
                 self._format_kwargs(kwargs),
-                self._format_response(raw_response),
+                self._format_response(self.get_response_content(raw_response)),
             )
         )
 
